package com.ruoyi.dimp.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.dimp.domain.DPatentEffectiveInfoPreDetail;
import com.ruoyi.dimp.domain.DPatentEffectiveInfoPreImp;
import com.ruoyi.report.domain.RzlViewStatisticsInfo;
import com.ruoyi.report.vo.LastSumDTO;
import com.ruoyi.reportpub.domain.DPatentPubInfo;
import com.ruoyi.system.domain.DFixAddressArea;
import com.ruoyi.dimp.domain.DPatentEffectiveInfo;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 专利有效导入Service接口
 *
 * @author ruoyi
 * @date 2023-03-19
 */
public interface IDPatentEffectiveInfoService extends IService<DPatentEffectiveInfo> {
    /**
     * 查询专利有效导入列表
     *
     * @param dPatentEffectiveInfo 专利有效导入
     * @return 专利有效导入集合
     * @date 2023-03-19
     */
    List<DPatentEffectiveInfo> queryList(DPatentEffectiveInfo dPatentEffectiveInfo);
    
    String importData(List<DPatentEffectiveInfoPreDetail> dataList, DPatentEffectiveInfoPreImp imp);
    
    DPatentEffectiveInfo doCleanData(DPatentPubInfo pubInfo,DPatentEffectiveInfo data,Map<String,DFixAddressArea>fixMap);
    void cleanData();
    void reMatch();
    void reMatch2();
    
    void reMatch3();
    void doRefreshHv() ;
    
    void deleteWidthImpBatch(String impBatch);
}
